/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */
AUI.add('liferay-search-facet-util', function (A) {
  var FACET_TERM_CLASS = 'facet-term';
  var FACET_TERM_SELECTED_CLASS = 'facet-term-selected';
  /**
   * Gets the ID by checking the `data-term-id` attribute and then `id` if
   * `data-term-id` is not defined.
   *
   * The default layout continues to use `data-term-id` in case the
   * original ID format `${namespace}_term_${index}` is expected, but
   * newer layouts (ADT) sometimes only use `id`.
   */

  function _getTermId(term) {
    return term.getAttribute('data-term-id') || term.id;
  }
  /**
   * Converts a NodeList to an array of nodes. This allows array
   * methods to be performed.
   * @param {NodeList} nodeList
   */


  function _transformNodeListToArray(nodeList) {
    var nodeArray = [];
    nodeList.forEach(function (node) {
      return nodeArray.push(node);
    });
    return nodeArray;
  }

  var FacetUtil = {
    addURLParameter: function addURLParameter(key, value, parameterArray) {
      key = encodeURIComponent(key);
      value = encodeURIComponent(value);
      parameterArray[parameterArray.length] = [key, value].join('=');
      return parameterArray;
    },
    changeSelection: function changeSelection(event) {
      event.preventDefault();
      var form = event.currentTarget.form;

      if (!form) {
        return;
      }

      var currentSelectedTermId = _getTermId(event.currentTarget);

      var facetTerms = document.querySelectorAll("#".concat(form.id, " .").concat(FACET_TERM_CLASS));

      var selectedTerms = _transformNodeListToArray(facetTerms).filter(function (term) {
        if (term.type === 'checkbox') {
          return term.checked;
        }

        var isCurrentTarget = _getTermId(term) === currentSelectedTermId;
        var isSelected = Array.prototype.includes.call(term.classList, FACET_TERM_SELECTED_CLASS);
        return isCurrentTarget ? !isSelected : isSelected;
      }).map(function (term) {
        return _getTermId(term);
      });

      FacetUtil.selectTerms(form, selectedTerms);
    },
    clearSelections: function clearSelections(event) {
      var form = A.one(event.target).ancestor('form');

      if (!form) {
        return;
      }

      var selections = [];
      FacetUtil.selectTerms(form._node, selections);
    },
    enableInputs: function enableInputs(inputs) {
      inputs.forEach(function (term) {
        Liferay.Util.toggleDisabled(term, false);
      });
    },
    removeStartParameter: function removeStartParameter(startParameterName, queryString) {
      var search = queryString;
      var hasQuestionMark = search[0] === '?';

      if (hasQuestionMark) {
        search = search.substr(1);
      }

      var parameterArray = search.split('&').filter(function (item) {
        return item.trim() !== '';
      });
      var newParameters = FacetUtil.removeURLParameters(startParameterName, parameterArray);
      search = newParameters.join('&');

      if (hasQuestionMark) {
        search = '?' + search;
      }

      return search;
    },
    removeURLParameters: function removeURLParameters(key, parameterArray) {
      key = encodeURIComponent(key);
      return parameterArray.filter(function (item) {
        var itemSplit = item.split('=');
        return !(itemSplit && itemSplit[0] === key);
      });
    },
    selectTerms: function selectTerms(form, selections) {
      var formParameterNameElement = document.querySelector('#' + form.id + ' input.facet-parameter-name');
      var startParameterNameElement = document.querySelector('#' + form.id + ' input.start-parameter-name');
      var search = document.location.search;

      if (startParameterNameElement) {
        search = FacetUtil.removeStartParameter(startParameterNameElement.value, search);
      }

      search = FacetUtil.updateQueryString(formParameterNameElement.value, selections, search);
      document.location.search = search;
    },
    setURLParameter: function setURLParameter(url, name, value) {
      var parts = url.split('?');
      var address = parts[0];
      var queryString = parts[1];

      if (!queryString) {
        queryString = '';
      }

      queryString = Liferay.Search.FacetUtil.updateQueryString(name, [value], queryString);
      return address + '?' + queryString;
    },
    setURLParameters: function setURLParameters(key, selections, parameterArray) {
      var newParameters = FacetUtil.removeURLParameters(key, parameterArray);
      newParameters = FacetUtil.removeURLParameters(key + 'From', newParameters);
      newParameters = FacetUtil.removeURLParameters(key + 'To', newParameters);
      selections.forEach(function (item) {
        newParameters = FacetUtil.addURLParameter(key, item, newParameters);
      });
      return newParameters;
    },
    updateQueryString: function updateQueryString(key, selections, queryString) {
      var search = queryString;
      var hasQuestionMark = search[0] === '?';

      if (hasQuestionMark) {
        search = search.substr(1);
      }

      var parameterArray = search.split('&').filter(function (item) {
        return item.trim() !== '';
      });
      var newParameters = FacetUtil.setURLParameters(key, selections, parameterArray);
      search = newParameters.join('&');

      if (hasQuestionMark) {
        search = '?' + search;
      }

      return search;
    }
  };
  Liferay.namespace('Search').FacetUtil = FacetUtil;
}, '', {
  requires: []
});
//# sourceMappingURL=facet_util.js.map