/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */
AUI.add('liferay-logo-editor', function (A) {
  var Lang = A.Lang;
  var LogoEditor = A.Component.create({
    ATTRS: {
      aspectRatio: {
        validator: Lang.isNumber,
        value: null
      },
      maxFileSize: {
        validator: Lang.isNumber,
        value: Liferay.PropsValues.UPLOAD_SERVLET_REQUEST_IMPL_MAX_SIZE
      },
      preserveRatio: {
        value: false
      },
      previewURL: {
        validator: Lang.isString,
        value: null
      },
      uploadURL: {
        validator: Lang.isString,
        value: null
      }
    },
    AUGMENTS: [Liferay.PortletBase],
    EXTENDS: A.Base,
    NAME: 'logoeditor',
    prototype: {
      _defUploadCompleteFn: function _defUploadCompleteFn(event) {
        var instance = this;
        var response = event.response;
        var portraitPreviewImg = instance._portraitPreviewImg;

        if (Lang.isObject(response)) {
          if (response.errorMessage) {
            instance._showError(response.errorMessage);

            instance._fileNameNode.set('value', '');
          }

          if (response.tempImageFileName) {
            var previewURL = instance.get('previewURL');
            var tempImageFileName = encodeURIComponent(response.tempImageFileName);
            previewURL = Liferay.Util.addParams(instance.get('namespace') + 'tempImageFileName=' + tempImageFileName, previewURL);
            previewURL = Liferay.Util.addParams('t=' + Date.now(), previewURL);
            portraitPreviewImg.attr('src', previewURL);
            instance.one('#previewURL').val(previewURL);
            instance.one('#tempImageFileName').val(response.tempImageFileName);
          }
        }

        portraitPreviewImg.removeClass('loading');

        if (instance._emptyResultMessage) {
          instance._emptyResultMessage.hide();
        }
      },
      _defUploadStartFn: function _defUploadStartFn() {
        var instance = this;

        instance._getMessageNode().remove();

        Liferay.Util.toggleDisabled(instance._submitButton, true);
      },
      _getMessageNode: function _getMessageNode(message, cssClass) {
        var instance = this;
        var messageNode = instance._messageNode;

        if (!messageNode) {
          messageNode = A.Node.create('<div></div>');
          instance._messageNode = messageNode;
        }

        if (message) {
          messageNode.html(message);
        }

        if (cssClass) {
          messageNode.removeClass('alert-danger').removeClass('alert-success');
          messageNode.addClass(cssClass);
        }

        return messageNode;
      },
      _onFileNameChange: function _onFileNameChange() {
        var instance = this;
        var formValidator = Liferay.Form.get(instance._formNode.attr('id')).formValidator;
        formValidator.validateField(instance._fileNameNode);

        if (instance._fileNameNode.val() && !formValidator.hasErrors()) {
          var imageCropper = instance._imageCropper;
          var portraitPreviewImg = instance._portraitPreviewImg;
          portraitPreviewImg.addClass('loading');
          portraitPreviewImg.attr('src', themeDisplay.getPathThemeImages() + '/spacer.png');

          if (imageCropper) {
            imageCropper.disable();
          }

          var form = document[instance.ns('fm')];
          instance.fire('uploadStart');
          Liferay.Util.fetch(instance.get('uploadURL'), {
            body: new FormData(form),
            method: 'POST'
          }).then(function (response) {
            return response.json();
          }).then(function (response) {
            instance.fire('uploadComplete', {
              response: response
            });
          });
        }
      },
      _onImageLoad: function _onImageLoad() {
        var instance = this;
        var imageCropper = instance._imageCropper;
        var portraitPreviewImg = instance._portraitPreviewImg;

        if (portraitPreviewImg.attr('src').indexOf('spacer.png') == -1) {
          var aspectRatio = instance.get('aspectRatio');
          var portraitPreviewImgHeight = portraitPreviewImg.height();
          var portraitPreviewImgWidth = portraitPreviewImg.width();
          var cropHeight = portraitPreviewImgHeight;
          var cropWidth = portraitPreviewImgWidth;

          if (aspectRatio) {
            if (cropHeight < cropWidth) {
              cropWidth = cropHeight;
            } else {
              cropHeight = cropWidth;
            }

            if (aspectRatio > 1) {
              cropHeight = cropWidth / aspectRatio;
            } else {
              cropWidth = cropHeight * aspectRatio;
            }
          }

          if (imageCropper) {
            imageCropper.enable();
            imageCropper.syncImageUI();
            imageCropper.setAttrs({
              cropHeight: cropHeight,
              cropWidth: cropWidth,
              x: 0,
              y: 0
            });
          } else {
            imageCropper = new A.ImageCropper({
              cropHeight: cropHeight,
              cropWidth: cropWidth,
              preserveRatio: instance.get('preserveRatio'),
              srcNode: portraitPreviewImg
            }).render();
            instance._imageCrop = A.one('.image-cropper-crop');
            instance._imageCropper = imageCropper;
          }

          instance._setCropBackgroundSize(portraitPreviewImgWidth, portraitPreviewImgHeight);

          Liferay.Util.toggleDisabled(instance._submitButton, false);
        }
      },
      _onSubmit: function _onSubmit() {
        var instance = this;
        var imageCropper = instance._imageCropper;
        var portraitPreviewImg = document.getElementById(instance.get('namespace') + 'portraitPreviewImg');

        if (imageCropper && portraitPreviewImg) {
          var region = imageCropper.get('region');
          var cropRegion = Liferay.Util.getCropRegion(portraitPreviewImg, region);

          instance._cropRegionNode.val(JSON.stringify(cropRegion));
        }
      },
      _setCropBackgroundSize: function _setCropBackgroundSize(width, height) {
        var instance = this;

        if (instance._imageCrop) {
          instance._imageCrop.setStyle('backgroundSize', width + 'px ' + height + 'px');
        }
      },
      _showError: function _showError(message) {
        Liferay.Util.openToast({
          message: message,
          type: 'danger'
        });
      },
      bindUI: function bindUI() {
        var instance = this;
        instance.publish('uploadComplete', {
          defaultFn: A.rbind('_defUploadCompleteFn', instance)
        });
        instance.publish('uploadStart', {
          defaultFn: A.rbind('_defUploadStartFn', instance)
        });

        instance._fileNameNode.on('change', instance._onFileNameChange, instance);

        instance._formNode.on('submit', instance._onSubmit, instance);

        instance._portraitPreviewImg.on('load', instance._onImageLoad, instance);
      },
      destructor: function destructor() {
        var instance = this;
        var imageCropper = instance._imageCropper;

        if (imageCropper) {
          imageCropper.destroy();
        }
      },
      initializer: function initializer() {
        var instance = this;
        instance.renderUI();
        instance.bindUI();
      },
      renderUI: function renderUI() {
        var instance = this;
        instance._cropRegionNode = instance.one('#cropRegion');
        instance._emptyResultMessage = instance.one('#emptyResultMessage');
        instance._fileNameNode = instance.one('#fileName');
        instance._formNode = instance.one('#fm');
        instance._portraitPreviewImg = instance.one('#portraitPreviewImg');
        instance._submitButton = instance.one('#submitButton');
      },
      resize: function resize() {
        var instance = this;
        var portraitPreviewImg = instance._portraitPreviewImg;

        if (portraitPreviewImg) {
          instance._setCropBackgroundSize(portraitPreviewImg.width(), portraitPreviewImg.height());
        }
      }
    }
  });
  Liferay.LogoEditor = LogoEditor;
}, '', {
  requires: ['aui-image-cropper', 'liferay-portlet-base']
});
//# sourceMappingURL=logo_editor.js.map